-- DirXML ASN1 Schema Definitions
-- Novell Inc.
-- 122 East 1700 South
-- Provo, UT 84606-6194

-- VeRsIoN=DirXML 2
-- CoPyRiGhT=(c) Copyright 1997-2003, Novell, Inc.  All rights reserved

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) NDS(1)  NDSAttributeType(4)
--                                            NDSAttributeSyntax(5)
--                                            NDSObjectClass(6)
--              revision number(1) sequence number(1)
------------------------------------------
-- One Additional Digit was added before the attribute or object
-- identifier to identify the release number.  This number reflects
-- the release number in which the object or attribute was added to the
-- definition.  The first release would have the ID 1 and count up from
-- there.
-- An example of the attribute of the first revision with sequence 1 would be:
-- 2 16 840 1 113719 1 1 4 1 1.
-- The attribute of the third revision with sequence 4 would be:
-- 2 16 840 1 113719 1 1 4 3 4.
------------------------------------------

NDSSchemaExtensions DEFINITIONS ::=
BEGIN

--
-- The XML Data holds XML encoded data
--
"XmlData" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 3}
}

--
-- The Association attribute serves as a junction point to other applications.
--
-- Issue: Should this attribute only exist on the Tao server that is providing
-- the replication to the "foreign" app? The example that I can think of where
-- we would not want this to be the case is if we have more than one Tao server
-- providing replication services to the same foreign app and it may be possible
-- for the same object to be replicated through any of the Tao servers providing
-- the junction point.
--
-- The association is syntax path where:
-- 	volumeDN = DN of the VR Driver
--	namespacetype = state of the association
--	path = Foreign Key
--
-- THE DirXML-Associations attribute is now part of the operational schema. 

--
-- The ShimAuthID provides the ID that will be passed to the App Shim to
-- allow for shim authentication to the foreign app.
--
"DirXML-ShimAuthID" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 5}
}

--
-- The ShimAuthPassword provides the password that will be passed to the App 
-- Shim to allow for shim authentication to the foreign app.
--
"DirXML-ShimAuthPassword" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_OCTET_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 6}
}

--
-- The ShimAuthServer provides information about the server that should be
-- used by the App Shim to authenticate.
--
"DirXML-ShimAuthServer" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 7}
}

--
-- The ShimAuthConfig provides any further information that should be
-- used by the App Shim for initial configuration.
--
"DirXML-ShimConfigInfo" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 8}
}

--
-- The Native Module specifies the name of the DLL/NLM/Shared Library that 
-- should be loaded to serve as the Shim for this driver. It is expected that
-- this library will provide a number of well defined entry points that are
-- the Shim Subscriber API
--
"DirXML-NativeModule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 9}
}

--
-- The Java Module specifies the name of the java class that should be loaded
-- to serve as the Shim for this driver. This class must provide an 
-- implementation of the com.novell.nds.vrdriver.SubscriberShim interface.
--
"DirXML-JavaModule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 10}
}

--
-- Contains the filter specification of what information will be allowed to
-- pass to/from the foreign app and NDS
--
"DirXML-DriverFilter" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 11}
}

--
-- This attribute references the container that holds the driver definitions
-- that are to be run on any given server. The Driver Set can be used by more
-- than one Tao Server.  This attribute is set in a server's pseudo-server
-- object.
--
"DirXML-DriverSetDN" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 12}
}

--
-- This contains one of three values that indicate if the driver 
-- 1) should be started automatically at NDS boot time (by the VRIM), 
-- 2) started manually by some user interface, or 
-- 3) is disabled and cannot be started until value is set to AUTO or MANUAL.
--
"DirXML-DriverStartOption" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 13}
}

--
-- This value indicates the current status of the driver on a specific system
-- OR the modification state of a Driver Filter on a Subscriber or Publisher
-- object.  
--
-- For a Driver State:
-- Currently supported states are STOPPED, STARTING, RUNNING, SHUTDOWN_PENDING.  
-- The STARTING and SHUTDOWN_PENDING states may be set via an administrative 
-- utility using the DDCSetIntegrationDriverState API functionality.
-- DDCGetIntegrationDriverState is available to allow a utility to retrieve 
-- the status of the specific driver instance.
--
-- For a Pub/Sub filter state:
-- Currently supported states are CURRENT and MODIFIED.
--
"DirXML-State" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 14}
}

--
-- The server list attribute holds the DNs of the servers that make use of a
-- given driver set
--
"DirXML-ServerList" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 15}
}

-- 
-- Serves as the beginning of the cached transaction window for a given driver
--
"DirXML-Timestamp" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_TIMESTAMP,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 16}
}

-- 
-- The Input Transform represents the XSLT processing that will be 
-- performed during a an attempt to auto-correlate a given subscription/publication
-- event. It is used to transform App native format into XDS.
--
-- This is a DN attribute that references an object of type XSLT Style Sheet
--
"DirXML-InputTransform" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 17}
}

-- 
-- The Output Transform represents the XSLT processing that will be 
-- performed during a an attempt to auto-correlate a given subscription/publication
-- event. It is used to transform XDS into App native format.
--
-- This is a DN attribute that references an object of type XSLT Style Sheet
--
"DirXML-OutputTransform" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 18}
}

-- 
-- The Mapping Rule represents the XML rule that will be used to map
-- class and attribute names between the NDS and Application namespaces
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-MappingRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 19}
}

-- 
-- The Placement Rule represents the XML rule that will be used to
-- place newly created objects into a hierchical namespace.
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-PlacementRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 20}
}

-- 
-- The Matching Rule represents the XML rule that will be used to
-- match up objects between the NDS and an Application
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-MatchingRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 21}
}

-- 
-- The Create Rule represents the XML rule that will be used to
-- decide whether or not to go ahead and create a new object
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-CreateRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 22}
}

-- 
-- The Event Transformation Rule represents the XML rule that will be used to
-- transform events from one type to another
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-EventTransformationRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 23}
}

-- 
-- The Driver Cache Limit holds the maximum size that the driver cache file can grow to
-- before causing a cache overflow condition 
--
"DirXML-DriverCacheLimit" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 24}
}

-- 
-- The Driver Trace Level is the maximimum level of DirXML trace message
-- to output for drivers in the Driver Set
--
"DirXML-DriverTraceLevel" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 25}
}

-- 
-- The Driver Trace Level is the maximimum level of XSL trace messages
-- to output for the XSL processor
--
"DirXML-XSLTraceLevel" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 26}
}

-- 
-- The Java Debug Port to specify the use of a debugging port on the
-- Java Virtual Machine, 0 = none, -1 = autoselect
--
"DirXML-JavaDebugPort" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 27}
}

-- 
-- The Java Trace File is where all Java System.out and System.err output can be logged
--
"DirXML-JavaTraceFile" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 28}
}

-- 
-- The Application Schema is where the XML that describes the Application Schema is stored
--
"DirXML-ApplicationSchema" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 29}
}

-- 
-- The DriverStorage is where a driver can store any information it may need
-- between invocations. The information is stored as XML.
--
"DirXML-DriverStorage" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 30}
}

-- 
-- The Command Transformation Rule represents the XML rule that will be used to
-- transform events from one type to another
--
-- This is a DN attribute that references an object of type DirXML-StyleSheet
--
-- Added for DirXML 1.1
"DirXML-CommandTransformationRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 31}
}

-- 
-- The Next Transformation allows DirXML-Rule and DirXML-Stylesheet objects to be
-- chained together
--
-- This is a DN attribute that references an object of type DirXML-StyleSheet or DirXML-Rule
--
-- Added for DirXML 1.1
"DirXML-NextTransformation" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 32}
}

--
-- The last log time identifies the last time DirXML logged an error to the
-- driver set, subscriber or publisher objects. 
--
-- Added for DirXML 1.1
"DirXML-LastLogTime" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_TIME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 33}
}

--
-- The status log contains the latest errors logged to the driver set, 
-- subscriber or publisher objects. 
--
-- Added for DirXML 1.1
--
-- Attribute Value format
--		string 1 - UTC seconds when value was added. 
-- 		string 2 - Error code or level (WARNING, ERROR)
--		string 3 - Error description
--		string 4 - Object name associated with error.
-- 
"DirXML-StatusLog" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_PER_REPLICA},
	SyntaxID		SYN_CI_LIST,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 34}
}

--
-- The log limit identifies the maximum number of DirXML errors to store on the Driver set,
-- publisher or subscriber objects. 
--
-- Added for DirXML 1.1
--
-- Bounds enforced by DirXML engine - not by schema definition.
--		Minimum - 50 (Default)
--		Maximum - 500
--
"DirXML-LogLimit" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 35}
}

--
-- The driver identification has the value that the driver reports as its 
-- identification value. This is used for licensing.
--
-- Added for DirXML 1.1
--
--
"DirXML-DriverId" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 36}
}

--
-- The driver identification has the value that the driver reports as its 
-- identification value. This is used for licensing.
--
-- Added for DirXML 1.1
--
--
"DirXML-DriverVersion" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 37}
}

--
-- The command attribute on the driver set is used to
-- pass XML-formatted commands to the DirXML engine
--
-- Added for DirXML 1.1
--
"DirXML-Command" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_PER_REPLICA},
	SyntaxID		SYN_OCTET_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 38}
}

--
-- The response attribute on the driver set is used by
-- the engine to report the results of processing commands
-- obtained from the DirXML-Command attribute.
--
-- Added for DirXML 1.1
--
"DirXML-Response" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_PER_REPLICA},
	SyntaxID		SYN_OCTET_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 39}
}

--
-- Reserved
--
-- Added for DirXML 1.1
--
"DirXML-Act1" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_HIDDEN_ATTR},
	SyntaxID		SYN_OCTET_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 40}
}

--
-- Reserved
--
-- Added for DirXML 1.1
--
"DirXML-Act2" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR},
	SyntaxID		SYN_TIMESTAMP,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 41}
}

--
-- Reserved
--
-- Added for DirXML 1.1
--
"DirXML-Act3" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE},
	SyntaxID		SYN_OCTET_LIST,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 42}
}

--
-- Icon for driver configuration wizard
--
-- Added for DirXML 1.1
--
"DirXML-DriverImage" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 43}
}

--
-- The local server guid attribute is used to cache the local server guid on the 
-- current driver set object. 
--
-- Added for DirXML 2 
--
"DirXML-ServerGUID" ATTRIBUTE ::=
{
   Operation	ADD,
   Flags	{DS_PER_REPLICA, DS_SIZED_ATTR, DS_SINGLE_VALUED_ATTR},
   SyntaxID	SYN_OCTET_STRING,
   LowerBound	16,
   UpperBound	16,
   ASN1ObjID		{2 16 840 1 113719 1 14 4 1 50}
}

-- 
-- The DirXML-TraceLevel is used to control tracing on an individual
-- driver level (Unfortunately, DirXML-DriverTraceLevel was already used
-- for logging, so it isn't available for the purpose)
--
-- Added for DirXML 2
--
"DirXML-TraceLevel" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 51}
}

-- 
-- The DirXML-TraceFile is used to specify trace files for individual drivers.
--
-- Added for DirXML 2
--
"DirXML-TraceFile" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 52}
}

-- 
-- The DirXML-TraceName is used to specify a short name for individual driver tracing.
--
-- Added for DirXML 2
--
"DirXML-TraceName" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 53}
}

-- 
-- The DirXML-ConfigValues is used to contain an XML document with Global Configuration
-- Value definitions.
--
-- Added for DirXML 2
--
"DirXML-ConfigValues" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 54}
}

--
-- The DirXML-LogEvents attribute contains a list of DirXML event ID's
-- that the engine should send to the logging services (RNS/Ontario)
--
-- Added for DirXML 2
--
"DirXML-LogEvents" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_READ_ONLY_ATTR, DS_PUBLIC_READ},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 55}
}


-- 
-- The Application Schema is where the XML that describes the Application Schema is stored
--
-- Added for DirXML 2
--
"DirXML-ConfigManifest" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 56}
}

-- 
-- Serves as the end of the cached transaction window for a given driver
--
-- Added for DirXML 2
--
"DirXML-Timestamp2" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_TIMESTAMP,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 57}
}

-- 
-- The DirXML-EngineControlValues attribute is used to contain an XML document with 
-- driver-specific Configuration Value definitions.
--
-- Added for DirXML 2
--
"DirXML-EngineControlValues" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 58}
}

--
-- The DirXML-NamedPasswords provides for named values that are obfuscated to 
-- provide a bit of security for sensitive driver configuration information. Things
-- like application passwords beyond the one in DirXML-ShimAuthPassword, etc.
--
-- Added for DirXML 2
--
"DirXML-NamedPasswords" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_PER_REPLICA, DS_READ_ONLY_ATTR, DS_HIDDEN_ATTR},
	SyntaxID		SYN_OCTET_LIST,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 59}
}

-- 
-- The DirXML-TraceSizeLimit is used to specify an approximate maximum size for
-- trace file data. The value is an integer number of kilobytes; zero has
-- the meaning "unlimited".
--
-- Added for DirXML 2
--
"DirXML-TraceSizeLimit" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 60}
}

--
-- With the Tao release of NDS, all objects in the tree will be candidates for
-- sychronization with foreign applications.
--
"Top" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-Associations"}
}

--
-- A driver set holds all drivers that are applicable for a give server.
-- The driver set should be defined as a seperate partition with a replica
-- placed on all Tao servers that will use this driver set.
--
"DirXML-DriverSet" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"Country", "Locality", "domain", "Organization", "Organizational Unit"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"DirXML-ServerList"},
	MayContain		{"DirXML-DriverTraceLevel"},
	MayContain		{"DirXML-XSLTraceLevel"},
	MayContain		{"DirXML-JavaDebugPort"},
	MayContain		{"DirXML-JavaTraceFile"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 1}
}

-- 
-- The driver is the focal point of configuration of replication from NDS to
-- foreign applications.
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-DriverSet"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"DirXML-DriverCacheLimit"},
	MayContain		{"DirXML-DriverStartOption"},
	MayContain		{"DirXML-ShimConfigInfo"},
	MayContain		{"DirXML-ShimAuthID"},
	MayContain		{"DirXML-ShimAuthPassword"},
	MayContain		{"DirXML-ShimAuthServer"},
	MayContain		{"DirXML-State"},
	MayContain		{"DirXML-NativeModule"},
	MayContain		{"DirXML-JavaModule"},
	MayContain		{"DirXML-InputTransform"},
	MayContain		{"DirXML-OutputTransform"},
	MayContain		{"DirXML-MappingRule"},
	MayContain		{"DirXML-ApplicationSchema"},
	MayContain		{"DirXML-DriverStorage"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 2}
}

--
-- Attributes that have been relocated from Tao Beta 3 to Beta 4
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"Private Key", "Public Key", "Security Equals"}
}

--
-- The relationship between a Driver object and the corresponding publisher
-- and/or subscriber objects is strictly by containment. There will be zero
-- or one subscriber/publisher objects for any given driver object. This
-- will be enforced by the Console One snap-in only.
--

-- 
-- The publisher contains all information necessary to allow a foreign
-- application to publish information to the Directory.
--
"DirXML-Publisher" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-Driver"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"Private Key"},
	MayContain		{"Public Key"},
	MayContain		{"DirXML-DriverFilter"},
	MayContain		{"DirXML-PlacementRule"},
	MayContain		{"DirXML-MatchingRule"},
	MayContain		{"DirXML-CreateRule"},
	MayContain		{"DirXML-EventTransformationRule"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 3}
}

--
-- Attributes that have been added for DirXML 1.1
--
"DirXML-Publisher" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-CommandTransformationRule"}
}

--
-- The subscriber contains all the information necessary to allow a foreign
-- application to subscribe to changes within the Directory.
--
"DirXML-Subscriber" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-Driver"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"DirXML-DriverFilter"},
	MayContain		{"DirXML-Timestamp"},
	MayContain		{"DirXML-PlacementRule"},
	MayContain		{"DirXML-MatchingRule"},
	MayContain		{"DirXML-CreateRule"},
	MayContain		{"DirXML-EventTransformationRule"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 4}
}

--
-- Attributes that have been added for DirXML 1.1
--
"DirXML-Subscriber" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-CommandTransformationRule"}
}

--
-- A general style sheet object is being added to hold XML styling information
--
"StyleSheet" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"Country", "Locality", "domain", "Organization", "Organizational Unit"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"XmlData"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 5}
}

-- 
-- DirXML Style sheets may also be contained by Driver Sets, Drivers, Publishers, 
-- and Subscribers
--
"DirXML-StyleSheet" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"StyleSheet"},
	ContainedBy		{"DirXML-Publisher", "DirXML-Subscriber", "DirXML-Driver"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 6}
}

--
-- Attributes that have been added for DirXML 1.1
--
"DirXML-StyleSheet" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-NextTransformation"}
}

--
-- A DirXML rule object is being added to hold rule information for the transformation 
-- of data to driver formats
--
"DirXML-Rule" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-Publisher", "DirXML-Subscriber", "DirXML-Driver"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"XmlData"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 7}
}

--
-- Attributes that have been added for DirXML 1.1
--
"DirXML-Rule" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-NextTransformation"}
}

--
-- With the DirXML release 1.1, the DirXML-DriverSet objects may contain
-- the DirXML-LastLogTime and DirXML-StatusLog attributes.
-- and DirXML-Command/DirXML-Response
-- and some reserved attributes.
--
"DirXML-DriverSet" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-LastLogTime", "DirXML-StatusLog", "DirXML-LogLimit"},
	MayContain		{"DirXML-Command", "DirXML-Response"},
	MayContain		{"DirXML-Act1", "DirXML-Act2", "DirXML-Act3"}
}

--
-- With the DirXML release 1.1, the DirXML-Subscriber objects may contain
-- the DirXML-LastLogTime and DirXML-StatusLog attributes.
--
"DirXML-Subscriber" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-LastLogTime", "DirXML-StatusLog"}
}

--
-- With the DirXML release 1.1, the DirXML-Publisher objects may contain
-- the DirXML-LastLogTime and DirXML-StatusLog attributes.
--
"DirXML-Publisher" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-LastLogTime", "DirXML-StatusLog"}
}

--
-- With the DirXML release 1.1, the DirXML-Driver objects may contain
-- the DirXML-DriverTraceLevel attribute to setup the status logging.
--
-- DirXML-DriverTraceLevel settings for the publisher and subscriber error logs. 
--		0 - Log errors and update last log time (Default).
--		1 - Log errors, warnings and update the last log time.
--		2 - Update last log time only.
--		3 - Turn off logging.
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-DriverTraceLevel", "DirXML-LogLimit" },
	MayContain		{"DirXML-DriverId"},
	MayContain		{"DirXML-DriverVersion"},
	MayContain		{"DirXML-Act2"},
	MayContain		{"DirXML-DriverImage"}
}

--
-- With the DirXML release 1.1SP1, the DirXML-Driver objects may contain
-- the DirXML-Act1 attribute
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-Act1"}
}

--
-- 	The local server guid is used to cache the local NCP server guid on the Driver set object.
--
-- Added for DirXML 2
--
"DirXML-DriverSet" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-ServerGUID"},
	MayContain		{"DirXML-ConfigValues"},
	MayContain		{"DirXML-LogEvents"},
	MayContain		{"DirXML-TraceSizeLimit"}

}

--
-- With the DirXML 2, the DirXML-Driver objects may contain
-- the DirXML-TraceLevel attribute, config value definitions
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-TraceLevel"},
	MayContain		{"DirXML-TraceFile"},
	MayContain		{"DirXML-TraceName"},
	MayContain		{"DirXML-DriverFilter"},
	MayContain		{"DirXML-ConfigValues"},
	MayContain		{"DirXML-LogEvents"},
	MayContain		{"DirXML-ConfigManifest"},
	MayContain		{"DirXML-EngineControlValues"},
	MayContain		{"DirXML-NamedPasswords"},
	MayContain		{"DirXML-TraceSizeLimit"}
}

--
-- With the DirXML 2, added DirXML-Timestamp2 to subscriber
-- objects
--
"DirXML-Subscriber" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-Timestamp2"}
}


END

